@@ -32,7 +32,7 @@ void	TI_Constructor(TABLE_INFO *self, const ConnectionClass *conn)
 		char	qual[32];
 
 		STR_TO_NAME(self->bestitem, OID_NAME);
-		sprintf(qual, "\"oid\" = %%u");
+		sprintf(qual, "\"%s\" = %%u", OID_NAME);
 		STR_TO_NAME(self->bestqual, qual);
 		TI_set_hasoids(self);
 		TI_set_hasoids_checked(self);
@@ -67,6 +67,7 @@ inolog("FI_Constructor reuse=%d\n", reuse);
 		FI_Destructor(&self, 1, FALSE);
 	memset(self, 0, sizeof(FIELD_INFO));
 	self->nullable = TRUE;
+	self->columnkey = -1;
 }
 void	FI_Destructor(FIELD_INFO **fi, int count, BOOL freeFI)
 {
