@@ -52,7 +52,7 @@ SetDlgStuff(HWND hdlg, const ConnInfo *ci)
 	SetDlgItemText(hdlg, IDC_PASSWORD, ci->password);
 	SetDlgItemText(hdlg, IDC_PORT, ci->port);
 
-	libpq_exist = LIBPQ_check();
+	libpq_exist = SSLLIB_check();
 mylog("libpq_exist=%d\n", libpq_exist);
 	if (libpq_exist)
 		ShowWindow(GetDlgItem(hdlg, IDC_NOTICE_USER), SW_HIDE);
@@ -586,7 +586,7 @@ ds_options2Proc(HWND hdlg,
 				case IDAPPLY:
 				case IDPREVPAGE:
 					ci = (ConnInfo *) GetWindowLongPtr(hdlg, DWLP_USER);
-					mylog("IDOK: got ci = %x\n", ci);
+					mylog("IDOK: got ci = %p\n", ci);
 
 					/* Readonly */
 					sprintf(ci->onlyread, "%d", IsDlgButtonChecked(hdlg, DS_READONLY));
