@@ -12,12 +12,16 @@
  *-------
  */
 
+#include "psqlodbc.h"
+
 #ifdef	USE_SSPI
 #include "sspisvcs.h"
 #endif /* USE_SSPI */
 #ifndef	NOT_USE_LIBPQ
 #include <libpq-fe.h>
+#ifdef USE_SSL
 #include <openssl/ssl.h>
+#endif /* USE_SSL */
 #endif /* NOT_USE_LIBPQ */
 #include "socket.h"
 #include "loadlib.h"
@@ -82,7 +86,9 @@ SOCK_Constructor(const ConnectionClass *conn)
 #endif /* USE_SSPI */
 #ifndef	NOT_USE_LIBPQ
 		rv->via_libpq = FALSE;
+#ifdef USE_SSL
 		rv->ssl = NULL;
+#endif
 		rv->pqconn = NULL;
 #endif /* NOT_USE_LIBPQ */
 		rv->pversion = 0;
@@ -134,7 +140,9 @@ SOCK_Destructor(SocketClass *self)
 			}
 			self->via_libpq = FALSE;
 			self->pqconn = NULL;
+#ifdef USE_SSL
 			self->ssl = NULL;
+#endif
 		}
 		else
 #endif /* NOT_USE_LIBPQ */
@@ -347,7 +355,12 @@ retry:
 			case 0:
 			case EINPROGRESS:
 			case EINTR:
+#ifdef EAGAIN
+			case EAGAIN:
+#endif /* EAGAIN */
+#if defined(EWOULDBLOCK) && (!defined(EAGAIN) || (EWOULDBLOCK != EAGAIN))
 			case EWOULDBLOCK:
+#endif /* EWOULDBLOCK */
 		    		break;
 			default:
 				SOCK_set_error(self, SOCKET_COULD_NOT_CONNECT, "Could not connect to remote socket immedaitely");
@@ -458,10 +471,10 @@ static int SOCK_wait_for_ready(SocketClass *sock, BOOL output, int retry_count)
 		no_timeout = FALSE;
 	else if (0  > retry_count)
 		no_timeout = TRUE;
-#ifndef	NOT_USE_LIBPQ
+#ifdef	USE_SSL
 	else if (sock && NULL == sock->ssl)
 		no_timeout = TRUE;
-#endif /* NOT_USE_LIBPQ */
+#endif /* USE_SSL */
 	do {
 		FD_ZERO(&fds);
 		FD_ZERO(&except_fds);
@@ -472,7 +485,7 @@ static int SOCK_wait_for_ready(SocketClass *sock, BOOL output, int retry_count)
 			tm.tv_sec = retry_count;
 			tm.tv_usec = 0;
 		}
-		ret = select((int) socket + 1, output ? NULL : &fds, output ? &fds : NULL, &except_fds, no_timeout ? NULL : &tm);
+		ret = select((int) sock->socket + 1, output ? NULL : &fds, output ? &fds : NULL, &except_fds, no_timeout ? NULL : &tm);
 		gerrno = SOCK_ERRNO;
 	} while (ret < 0 && EINTR == gerrno);
 	if (retry_count < 0)
@@ -806,7 +819,12 @@ SOCK_flush_output(SocketClass *self)
 				case EINTR:
 					continue;
 					break;
+#ifdef EAGAIN
+				case EAGAIN:
+#endif /* EAGAIN */
+#if defined(EWOULDBLOCK) && (!defined(EAGAIN) || (EWOULDBLOCK != EAGAIN))
 				case EWOULDBLOCK:
+#endif /* EWOULDBLOCK */
 					retry_count++;
 					if (SOCK_wait_for_ready(self, TRUE, retry_count) >= 0)
 						continue;
@@ -858,7 +876,12 @@ mylog("Lasterror=%d\n", gerrno);
 				case	EINTR:
 					goto retry;
 					break;
+#ifdef EAGAIN
+				case	EAGAIN:
+#endif /* EAGAIN */
+#if defined(EWOULDBLOCK) && (!defined(EAGAIN) || (EWOULDBLOCK != EAGAIN))
 				case	EWOULDBLOCK:
+#endif /* EWOULDBLOCK */
 					retry_count++;
 					if (SOCK_wait_for_ready(self, FALSE, retry_count) >= 0)
 						goto retry;
@@ -932,7 +955,12 @@ SOCK_put_next_byte(SocketClass *self, UCHAR next_byte)
 				{
 					case	EINTR:
 						continue;
+#ifdef EAGAIN
+					case	EAGAIN:
+#endif /* EAGAIN */
+#if defined(EWOULDBLOCK) && (!defined(EAGAIN) || (EWOULDBLOCK != EAGAIN))
 					case	EWOULDBLOCK:
+#endif /* EWOULDBLOCK */
 						retry_count++;
 						if (SOCK_wait_for_ready(self, TRUE, retry_count) >= 0)
 							continue;
